Re: [PATCH RFC V8 0/17] Paravirtualized ticket spinlocks

6 messages, 4 authors, 2012-05-08 · open the first message on its own page

Re: [PATCH RFC V8 0/17] Paravirtualized ticket spinlocks

From: Avi Kivity <hidden>
Date: 2012-05-07 13:50:03

On 05/07/2012 04:46 PM, Srivatsa Vaddagiri wrote:
* Raghavendra K T [off-list ref] [2012-05-07 19:08:51]:
quoted
I 'll get hold of a PLE mc  and come up with the numbers soon. but I
'll expect the improvement around 1-3% as it was in last version.
Deferring preemption (when vcpu is holding lock) may give us better than 1-3% 
results on PLE hardware. Something worth trying IMHO.
Is the improvement so low, because PLE is interfering with the patch, or
because PLE already does a good job?

-- 
error compiling committee.c: too many arguments to function

Re: [PATCH RFC V8 0/17] Paravirtualized ticket spinlocks

From: Raghavendra K T <hidden>
Date: 2012-05-07 13:53:59

On 05/07/2012 07:19 PM, Avi Kivity wrote:
On 05/07/2012 04:46 PM, Srivatsa Vaddagiri wrote:
quoted
* Raghavendra K T[off-list ref]  [2012-05-07 19:08:51]:
quoted
I 'll get hold of a PLE mc  and come up with the numbers soon. but I
'll expect the improvement around 1-3% as it was in last version.
Deferring preemption (when vcpu is holding lock) may give us better than 1-3%
results on PLE hardware. Something worth trying IMHO.
Is the improvement so low, because PLE is interfering with the patch, or
because PLE already does a good job?
It is because PLE already does a good job (of not burning cpu). The
1-3% improvement is because, patchset knows atleast who is next to hold
lock, which is lacking in PLE.

Re: [PATCH RFC V8 0/17] Paravirtualized ticket spinlocks

From: Srivatsa Vaddagiri <hidden>
Date: 2012-05-07 13:55:24

* Avi Kivity [off-list ref] [2012-05-07 16:49:25]:
quoted
Deferring preemption (when vcpu is holding lock) may give us better than 1-3% 
results on PLE hardware. Something worth trying IMHO.
Is the improvement so low, because PLE is interfering with the patch, or
because PLE already does a good job?
I think its latter (PLE already doing a good job). 

- vatsa

Re: [PATCH RFC V8 0/17] Paravirtualized ticket spinlocks

From: Jeremy Fitzhardinge <hidden>
Date: 2012-05-07 23:15:46

On 05/07/2012 06:49 AM, Avi Kivity wrote:
On 05/07/2012 04:46 PM, Srivatsa Vaddagiri wrote:
quoted
* Raghavendra K T [off-list ref] [2012-05-07 19:08:51]:
quoted
I 'll get hold of a PLE mc  and come up with the numbers soon. but I
'll expect the improvement around 1-3% as it was in last version.
Deferring preemption (when vcpu is holding lock) may give us better than 1-3% 
results on PLE hardware. Something worth trying IMHO.
Is the improvement so low, because PLE is interfering with the patch, or
because PLE already does a good job?
How does PLE help with ticket scheduling on unlock?  I thought it would
just help with the actual spin loops.

    J

Re: [PATCH RFC V8 0/17] Paravirtualized ticket spinlocks

From: Raghavendra K T <hidden>
Date: 2012-05-08 01:13:31

On 05/08/2012 04:45 AM, Jeremy Fitzhardinge wrote:
On 05/07/2012 06:49 AM, Avi Kivity wrote:
quoted
On 05/07/2012 04:46 PM, Srivatsa Vaddagiri wrote:
quoted
* Raghavendra K T[off-list ref]  [2012-05-07 19:08:51]:
quoted
I 'll get hold of a PLE mc  and come up with the numbers soon. but I
'll expect the improvement around 1-3% as it was in last version.
Deferring preemption (when vcpu is holding lock) may give us better than 1-3%
results on PLE hardware. Something worth trying IMHO.
Is the improvement so low, because PLE is interfering with the patch, or
because PLE already does a good job?
How does PLE help with ticket scheduling on unlock?  I thought it would
just help with the actual spin loops.
Hmm. This strikes something to me. I think I should replace while 1 hog
in with some *real job*  to measure over-commit case. I hope to see
greater improvements because of fairness and scheduling of the
patch-set.

May be all the way I was measuring something equal to 1x case.

Re: [PATCH RFC V8 0/17] Paravirtualized ticket spinlocks

From: Avi Kivity <hidden>
Date: 2012-05-08 09:10:21

On 05/08/2012 02:15 AM, Jeremy Fitzhardinge wrote:
On 05/07/2012 06:49 AM, Avi Kivity wrote:
quoted
On 05/07/2012 04:46 PM, Srivatsa Vaddagiri wrote:
quoted
* Raghavendra K T [off-list ref] [2012-05-07 19:08:51]:
quoted
I 'll get hold of a PLE mc  and come up with the numbers soon. but I
'll expect the improvement around 1-3% as it was in last version.
Deferring preemption (when vcpu is holding lock) may give us better than 1-3% 
results on PLE hardware. Something worth trying IMHO.
Is the improvement so low, because PLE is interfering with the patch, or
because PLE already does a good job?
How does PLE help with ticket scheduling on unlock?  I thought it would
just help with the actual spin loops.
PLE yields to up a random vcpu, hoping it is the lock holder.  This
patchset wakes up the right vcpu.  For small vcpu counts the difference
is a few bad wakeups (and even a bad wakeup sometimes works, since it
can put the spinner to sleep for a bit).  I expect that large vcpu
counts would show a greater difference.

-- 
error compiling committee.c: too many arguments to function
Keyboard shortcuts
hback out one level
jnext message in thread
kprevious message in thread
ldrill in
Escclose help / fold thread tree
?toggle this help